Learn R Programming

speedytax (version 1.0.4)

read_tax_example: Get path to example taxonomy files

Description

Access the files in speedyseq's inst/extdata sub-directory

Usage

read_tax_example(file = NULL)

Value

Returns the full path to the requested file from the package sub-directory inst/extdata if it exists, or a list of the files in the directory if no file is specified.

Arguments

file

Name of file to return.

Examples

Run this code
read_tax_example()
read_tax_example("rdp_table.tsv")

Run the code above in your browser using DataLab